@@ -3,6 +3,7 @@ package js_parser
 import (
 	"fmt"
 
+	"github.com/evanw/esbuild/internal/compat"
 	"github.com/evanw/esbuild/internal/helpers"
 	"github.com/evanw/esbuild/internal/js_ast"
 	"github.com/evanw/esbuild/internal/js_lexer"
@@ -23,7 +24,7 @@ func (p *jsonParser) parseMaybeTrailingComma(closeToken js_lexer.T) bool {
 	p.lexer.Expect(js_lexer.TComma)
 
 	if p.lexer.Token == closeToken {
-		if !p.options.AllowTrailingCommas {
+		if p.options.Flavor == js_lexer.JSON {
 			p.log.AddError(&p.tracker, commaRange, "JSON does not support trailing commas")
 		}
 		return false
@@ -142,6 +143,14 @@ func (p *jsonParser) parseExpr() js_ast.Expr {
 				Key:        key,
 				ValueOrNil: value,
 			}
+
+			// The key "__proto__" must not be a string literal in JavaScript because
+			// that actually modifies the prototype of the object. This can be
+			// avoided by using a computed property key instead of a string literal.
+			if helpers.UTF16EqualsString(keyString, "__proto__") && !p.options.UnsupportedJSFeatures.Has(compat.ObjectExtensions) {
+				property.Flags |= js_ast.PropertyIsComputed
+			}
+
 			properties = append(properties, property)
 		}
 
@@ -163,9 +172,9 @@ func (p *jsonParser) parseExpr() js_ast.Expr {
 }
 
 type JSONOptions struct {
-	AllowComments       bool
-	AllowTrailingCommas bool
-	ErrorSuffix         string
+	UnsupportedJSFeatures compat.JSFeature
+	Flavor                js_lexer.JSONFlavor
+	ErrorSuffix           string
 }
 
 func ParseJSON(log logger.Log, source logger.Source, options JSONOptions) (result js_ast.Expr, ok bool) {
@@ -188,7 +197,7 @@ func ParseJSON(log logger.Log, source logger.Source, options JSONOptions) (resul
 		source:                         source,
 		tracker:                        logger.MakeLineColumnTracker(&source),
 		options:                        options,
-		lexer:                          js_lexer.NewLexerJSON(log, source, options.AllowComments, options.ErrorSuffix),
+		lexer:                          js_lexer.NewLexerJSON(log, source, options.Flavor, options.ErrorSuffix),
 		suppressWarningsAboutWeirdCode: helpers.IsInsideNodeModules(source.KeyPath.Text),
 	}
 
